==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MSY_manipulation.h <==
S_Pointer MSY_eval_contains (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_genident (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_indets (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

MUPbool MSY_indets ( 		S_Pointer	s,
				S_Pointer	*assmem,
				long		type,
				MUPbool		enter,
                                S_Pointer       call );

S_Pointer MSY_eval_hold (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_append (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_text2expr (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_expr2text (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_level (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_eval (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_float (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_bool (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_expand_spec(	S_Pointer	 expr,
				short		 spec,
				short		 cat);

S_Pointer MSY_eval_map (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

void MSY_select_opds(		S_Pointer	 *fcall,	/* In-OUT */
				S_Pointer	 expr,
				S_Pointer	 *res,         /* IN-OUT */
				long		 arg1,
				long		 nargs,
				long		 eval_type );

S_Pointer MSY_eval_select (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_split (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_select_split (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec,
				MUPbool		 do_split );

S_Pointer MSY_eval_zip (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

long MSY_eval_val_intern ( 	S_Pointer	 t,
				S_Pointer	 exec);

S_Pointer MSY_eval_val (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MSY_manipulation.h <==
#ifndef __MSY_manipulation_h__
#define __MSY_manipulation_h__

S_Pointer MSY_eval_contains (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_genident (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_indets (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

bool MSY_indets ( 		S_Pointer	s,
				S_Pointer	*assmem,
				long		type,
				bool		enter,
                                S_Pointer       call );

S_Pointer MSY_eval_hold (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_append (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_text2expr (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_expr2text (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_level (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_eval (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_float (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_bool (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_expand_spec(	S_Pointer	 expr,
				short		 spec,
				short		 cat);

S_Pointer MSY_eval_map (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

void MSY_select_opds(		S_Pointer	 *fcall,	/* In-OUT */
				S_Pointer	 expr,
				S_Pointer	 *res,         /* IN-OUT */
				long		 arg1,
				long		 nargs,
				long		 eval_type );

S_Pointer MSY_eval_select (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_eval_split (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSY_select_split (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec,
				bool		 do_split );

S_Pointer MSY_eval_zip (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

long MSY_eval_val_intern ( 	S_Pointer	 t,
				S_Pointer	 exec);

S_Pointer MSY_eval_val (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

#endif // ! __MSY_manipulation_h__
